install_prolog_profile

Function install_prolog_profile 

pub fn install_prolog_profile(
    cx: &mut Cx,
    registry: &mut ProfileRegistry,
) -> Result<LanguageProfile>
Installs the Prolog profile into a ProfileRegistry.

The Prolog lib is loaded first so the profile symbol and callable surface are available together in the same context.